@@ -1,6 +1,7 @@
 # coding: utf-8
 # atomman imports
 from .aslist import aslist, iaslist
+from .screen_input import screen_input
 from .axes_check import axes_check
 from .atomic_info import *
 from .atomic_info import __all__ as atomic_info_all
@@ -16,7 +17,7 @@ from . import miller
 
 __all__ = ['axes_check', 'compositionstr', 'duplicates_allclose', 'vect_angle',
            'uber_open_rmode', 'indexstr', 'filltemplate', 'miller', 'aslist',
-           'iaslist']
+           'iaslist', 'screen_input']
 __all__.extend(atomic_info_all)
 __all__.extend(crystalsystem_all)
 __all__.sort()
\ No newline at end of file
